@@ -34,7 +34,6 @@ import static org.apache.gravitino.Configs.VERSION_RETENTION_COUNT;
 import static org.apache.gravitino.catalog.hadoop.HadoopCatalog.CATALOG_PROPERTIES_META;
 import static org.apache.gravitino.catalog.hadoop.HadoopCatalog.FILESET_PROPERTIES_META;
 import static org.apache.gravitino.catalog.hadoop.HadoopCatalog.SCHEMA_PROPERTIES_META;
-import static org.apache.gravitino.connector.BaseCatalog.CATALOG_BYPASS_PREFIX;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.when;
 
@@ -42,6 +41,7 @@ import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Maps;
 import java.io.File;
 import java.io.IOException;
+import java.net.ConnectException;
 import java.nio.file.Paths;
 import java.util.Arrays;
 import java.util.Map;
@@ -50,18 +50,25 @@ import java.util.UUID;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import org.apache.commons.io.FileUtils;
+import org.apache.commons.lang3.reflect.FieldUtils;
 import org.apache.gravitino.Catalog;
 import org.apache.gravitino.Config;
 import org.apache.gravitino.EntityStore;
 import org.apache.gravitino.EntityStoreFactory;
+import org.apache.gravitino.GravitinoEnv;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.Schema;
 import org.apache.gravitino.SchemaChange;
 import org.apache.gravitino.StringIdentifier;
+import org.apache.gravitino.audit.CallerContext;
+import org.apache.gravitino.audit.FilesetAuditConstants;
+import org.apache.gravitino.audit.FilesetDataOperation;
 import org.apache.gravitino.connector.CatalogInfo;
 import org.apache.gravitino.connector.HasPropertyMetadata;
 import org.apache.gravitino.connector.PropertiesMetadata;
+import org.apache.gravitino.connector.PropertyEntry;
+import org.apache.gravitino.exceptions.GravitinoRuntimeException;
 import org.apache.gravitino.exceptions.NoSuchFilesetException;
 import org.apache.gravitino.exceptions.NoSuchSchemaException;
 import org.apache.gravitino.exceptions.NonEmptySchemaException;
@@ -70,6 +77,7 @@ import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.file.FilesetChange;
 import org.apache.gravitino.storage.IdGenerator;
 import org.apache.gravitino.storage.RandomIdGenerator;
+import org.apache.gravitino.storage.relational.RelationalEntityStore;
 import org.apache.gravitino.storage.relational.service.CatalogMetaService;
 import org.apache.gravitino.storage.relational.service.MetalakeMetaService;
 import org.apache.gravitino.utils.NameIdentifierUtil;
@@ -226,18 +234,10 @@ public class TestHadoopCatalogOperations {
 
     CatalogInfo catalogInfo = randomCatalogInfo();
     ops.initialize(emptyProps, catalogInfo, HADOOP_PROPERTIES_METADATA);
-    Configuration conf = ops.hadoopConf;
+    Configuration conf = ops.getHadoopConf();
     String value = conf.get("fs.defaultFS");
     Assertions.assertEquals("file:///", value);
 
-    emptyProps.put(CATALOG_BYPASS_PREFIX + "fs.defaultFS", "hdfs://localhost:9000");
-    ops.initialize(emptyProps, catalogInfo, HADOOP_PROPERTIES_METADATA);
-    Configuration conf1 = ops.hadoopConf;
-    String value1 = conf1.get("fs.defaultFS");
-    Assertions.assertEquals("hdfs://localhost:9000", value1);
-
-    Assertions.assertFalse(ops.catalogStorageLocation.isPresent());
-
     emptyProps.put(HadoopCatalogPropertiesMetadata.LOCATION, "file:///tmp/catalog");
     ops.initialize(emptyProps, catalogInfo, HADOOP_PROPERTIES_METADATA);
     Assertions.assertTrue(ops.catalogStorageLocation.isPresent());
@@ -673,33 +673,68 @@ public class TestHadoopCatalogOperations {
   }
 
   @Test
-  public void testFormalizePath() throws IOException {
+  public void testFormalizePath() throws IOException, IllegalAccessException {
 
     String[] paths =
-        new String[] {
-          "tmp/catalog",
-          "/tmp/catalog",
-          "file:/tmp/catalog",
-          "file:///tmp/catalog",
-          "hdfs://localhost:9000/tmp/catalog",
-          "s3://bucket/tmp/catalog",
-          "gs://bucket/tmp/catalog"
-        };
+        new String[] {"tmp/catalog", "/tmp/catalog", "file:/tmp/catalog", "file:///tmp/catalog"};
 
     String[] expected =
         new String[] {
           "file:" + Paths.get("").toAbsolutePath() + "/tmp/catalog",
           "file:/tmp/catalog",
           "file:/tmp/catalog",
-          "file:/tmp/catalog",
-          "hdfs://localhost:9000/tmp/catalog",
-          "s3://bucket/tmp/catalog",
-          "gs://bucket/tmp/catalog"
+          "file:/tmp/catalog"
         };
 
-    for (int i = 0; i < paths.length; i++) {
-      Path actual = HadoopCatalogOperations.formalizePath(new Path(paths[i]), new Configuration());
-      Assertions.assertEquals(expected[i], actual.toString());
+    HasPropertyMetadata hasPropertyMetadata =
+        new HasPropertyMetadata() {
+          @Override
+          public PropertiesMetadata tablePropertiesMetadata() throws UnsupportedOperationException {
+            return null;
+          }
+
+          @Override
+          public PropertiesMetadata catalogPropertiesMetadata()
+              throws UnsupportedOperationException {
+            return new PropertiesMetadata() {
+              @Override
+              public Map<String, PropertyEntry<?>> propertyEntries() {
+                return new HadoopCatalogPropertiesMetadata().propertyEntries();
+              }
+            };
+          }
+
+          @Override
+          public PropertiesMetadata schemaPropertiesMetadata()
+              throws UnsupportedOperationException {
+            return null;
+          }
+
+          @Override
+          public PropertiesMetadata filesetPropertiesMetadata()
+              throws UnsupportedOperationException {
+            return null;
+          }
+
+          @Override
+          public PropertiesMetadata topicPropertiesMetadata() throws UnsupportedOperationException {
+            return null;
+          }
+        };
+
+    try {
+      FieldUtils.writeField(
+          GravitinoEnv.getInstance(), "entityStore", new RelationalEntityStore(), true);
+      try (HadoopCatalogOperations hadoopCatalogOperations = new HadoopCatalogOperations()) {
+        Map<String, String> map = ImmutableMap.of("default-filesystem", "file:///");
+        hadoopCatalogOperations.initialize(map, null, hasPropertyMetadata);
+        for (int i = 0; i < paths.length; i++) {
+          Path actual = hadoopCatalogOperations.formalizePath(new Path(paths[i]), map);
+          Assertions.assertEquals(expected[i], actual.toString());
+        }
+      }
+    } finally {
+      FieldUtils.writeField(GravitinoEnv.getInstance(), "entityStore", null, true);
     }
   }
 
@@ -736,7 +771,7 @@ public class TestHadoopCatalogOperations {
     String name = "fileset27";
     Fileset fileset = createFileset(name, schemaName, comment, Fileset.Type.MANAGED, null, null);
 
-    FilesetChange change1 = FilesetChange.removeComment();
+    FilesetChange change1 = FilesetChange.updateComment(null);
     try (SecureHadoopCatalogOperations ops = new SecureHadoopCatalogOperations(store)) {
       ops.initialize(Maps.newHashMap(), randomCatalogInfo(), HADOOP_PROPERTIES_METADATA);
       NameIdentifier filesetIdent = NameIdentifier.of("m1", "c1", schemaName, name);
@@ -762,6 +797,161 @@ public class TestHadoopCatalogOperations {
                 ImmutableMap.of()));
   }
 
+  @Test
+  void testTrailSlash() throws IOException {
+    try (SecureHadoopCatalogOperations ops = new SecureHadoopCatalogOperations(store)) {
+
+      String location = "hdfs://localhost:9000";
+      Map<String, String> catalogProperties = Maps.newHashMap();
+      catalogProperties.put(HadoopCatalogPropertiesMetadata.LOCATION, location);
+
+      ops.initialize(catalogProperties, randomCatalogInfo(), HADOOP_PROPERTIES_METADATA);
+
+      String schemaName = "schema1024";
+      NameIdentifier nameIdentifier = NameIdentifierUtil.ofSchema("m1", "c1", schemaName);
+
+      Map<String, String> schemaProperties = Maps.newHashMap();
+      schemaProperties.put(HadoopCatalogPropertiesMetadata.LOCATION, "hdfs://localhost:9000/user1");
+      StringIdentifier stringId = StringIdentifier.fromId(idGenerator.nextId());
+      schemaProperties =
+          Maps.newHashMap(StringIdentifier.newPropertiesWithId(stringId, schemaProperties));
+
+      Map<String, String> finalSchemaProperties = schemaProperties;
+
+      // If not fixed by #5296, this method will throw java.lang.IllegalArgumentException:
+      // java.net.URISyntaxException: Relative path in absolute URI: hdfs://localhost:9000schema1024
+      // After #5296, this method will throw java.lang.RuntimeException: Failed to create
+      // schema m1.c1.schema1024 location hdfs://localhost:9000/user1
+      Exception exception =
+          Assertions.assertThrows(
+              Exception.class,
+              () -> ops.createSchema(nameIdentifier, "comment", finalSchemaProperties));
+      Assertions.assertTrue(exception.getCause() instanceof ConnectException);
+    }
+  }
+
+  @Test
+  public void testGetFileLocation() throws IOException {
+    String schemaName = "schema1024";
+    String comment = "comment1024";
+    String schemaPath = TEST_ROOT_PATH + "/" + schemaName;
+    createSchema(schemaName, comment, null, schemaPath);
+
+    String catalogName = "c1";
+    String name = "fileset1024";
+    String storageLocation = TEST_ROOT_PATH + "/" + catalogName + "/" + schemaName + "/" + name;
+    Fileset fileset =
+        createFileset(name, schemaName, comment, Fileset.Type.MANAGED, null, storageLocation);
+
+    try (SecureHadoopCatalogOperations ops = new SecureHadoopCatalogOperations(store)) {
+      ops.initialize(Maps.newHashMap(), randomCatalogInfo(), HADOOP_PROPERTIES_METADATA);
+      NameIdentifier filesetIdent = NameIdentifier.of("m1", "c1", schemaName, name);
+      // test sub path starts with "/"
+      String subPath1 = "/test/test.parquet";
+      String fileLocation1 = ops.getFileLocation(filesetIdent, subPath1);
+      Assertions.assertEquals(
+          String.format("%s%s", fileset.storageLocation(), subPath1), fileLocation1);
+
+      // test sub path not starts with "/"
+      String subPath2 = "test/test.parquet";
+      String fileLocation2 = ops.getFileLocation(filesetIdent, subPath2);
+      Assertions.assertEquals(
+          String.format("%s/%s", fileset.storageLocation(), subPath2), fileLocation2);
+
+      // test sub path is null
+      String subPath3 = null;
+      Assertions.assertThrows(
+          IllegalArgumentException.class, () -> ops.getFileLocation(filesetIdent, subPath3));
+
+      // test sub path is blank but not null
+      String subPath4 = "";
+      String fileLocation3 = ops.getFileLocation(filesetIdent, subPath4);
+      Assertions.assertEquals(fileset.storageLocation(), fileLocation3);
+    }
+
+    // test mount a single file
+    String filesetName2 = "test_get_file_location_2";
+    String filesetLocation2 =
+        TEST_ROOT_PATH + "/" + catalogName + "/" + schemaName + "/" + filesetName2;
+    Path filesetLocationPath2 = new Path(filesetLocation2);
+    createFileset(filesetName2, schemaName, comment, Fileset.Type.MANAGED, null, filesetLocation2);
+    try (HadoopCatalogOperations ops = new HadoopCatalogOperations(store);
+        FileSystem localFileSystem = filesetLocationPath2.getFileSystem(new Configuration())) {
+      ops.initialize(Maps.newHashMap(), randomCatalogInfo(), HADOOP_PROPERTIES_METADATA);
+      NameIdentifier filesetIdent = NameIdentifier.of("m1", "c1", schemaName, filesetName2);
+      // replace fileset location to a single file
+      Assertions.assertTrue(localFileSystem.exists(filesetLocationPath2));
+      Assertions.assertTrue(localFileSystem.getFileStatus(filesetLocationPath2).isDirectory());
+      localFileSystem.delete(filesetLocationPath2, true);
+      localFileSystem.create(filesetLocationPath2);
+      Assertions.assertTrue(localFileSystem.exists(filesetLocationPath2));
+      Assertions.assertTrue(localFileSystem.getFileStatus(filesetLocationPath2).isFile());
+
+      String subPath = "/year=2024/month=07/day=22/test.parquet";
+      Map<String, String> contextMap = Maps.newHashMap();
+      contextMap.put(
+          FilesetAuditConstants.HTTP_HEADER_FILESET_DATA_OPERATION,
+          FilesetDataOperation.RENAME.name());
+      CallerContext callerContext = CallerContext.builder().withContext(contextMap).build();
+      CallerContext.CallerContextHolder.set(callerContext);
+
+      Assertions.assertThrows(
+          GravitinoRuntimeException.class, () -> ops.getFileLocation(filesetIdent, subPath));
+    } finally {
+      CallerContext.CallerContextHolder.remove();
+    }
+
+    // test rename with an empty subPath
+    String filesetName3 = "test_get_file_location_3";
+    String filesetLocation3 =
+        TEST_ROOT_PATH + "/" + catalogName + "/" + schemaName + "/" + filesetName3;
+    Path filesetLocationPath3 = new Path(filesetLocation3);
+    createFileset(filesetName3, schemaName, comment, Fileset.Type.MANAGED, null, filesetLocation3);
+    try (HadoopCatalogOperations ops = new HadoopCatalogOperations(store);
+        FileSystem localFileSystem = filesetLocationPath3.getFileSystem(new Configuration())) {
+      ops.initialize(Maps.newHashMap(), randomCatalogInfo(), HADOOP_PROPERTIES_METADATA);
+      NameIdentifier filesetIdent = NameIdentifier.of("m1", "c1", schemaName, filesetName3);
+      // replace fileset location to a single file
+      Assertions.assertTrue(localFileSystem.exists(filesetLocationPath3));
+      Assertions.assertTrue(localFileSystem.getFileStatus(filesetLocationPath3).isDirectory());
+      localFileSystem.delete(filesetLocationPath3, true);
+      localFileSystem.create(filesetLocationPath3);
+      Assertions.assertTrue(localFileSystem.exists(filesetLocationPath3));
+      Assertions.assertTrue(localFileSystem.getFileStatus(filesetLocationPath3).isFile());
+
+      Map<String, String> contextMap = Maps.newHashMap();
+      contextMap.put(
+          FilesetAuditConstants.HTTP_HEADER_FILESET_DATA_OPERATION,
+          FilesetDataOperation.RENAME.name());
+      CallerContext callerContext = CallerContext.builder().withContext(contextMap).build();
+      CallerContext.CallerContextHolder.set(callerContext);
+      Assertions.assertThrows(
+          GravitinoRuntimeException.class, () -> ops.getFileLocation(filesetIdent, ""));
+    }
+
+    // test storage location end with "/"
+    String filesetName4 = "test_get_file_location_4";
+    String filesetLocation4 =
+        TEST_ROOT_PATH + "/" + catalogName + "/" + schemaName + "/" + filesetName4 + "/";
+    NameIdentifier filesetIdent = NameIdentifier.of("m1", "c1", schemaName, name);
+    Fileset mockFileset = Mockito.mock(Fileset.class);
+    when(mockFileset.name()).thenReturn(filesetName4);
+    when(mockFileset.storageLocation()).thenReturn(filesetLocation4);
+
+    try (HadoopCatalogOperations mockOps = Mockito.mock(HadoopCatalogOperations.class)) {
+      mockOps.hadoopConf = new Configuration();
+      when(mockOps.loadFileset(filesetIdent)).thenReturn(mockFileset);
+      when(mockOps.getConf()).thenReturn(Maps.newHashMap());
+      String subPath = "/test/test.parquet";
+      when(mockOps.getFileLocation(filesetIdent, subPath)).thenCallRealMethod();
+      when(mockOps.getFileSystem(Mockito.any(), Mockito.any()))
+          .thenReturn(FileSystem.getLocal(new Configuration()));
+      String fileLocation = mockOps.getFileLocation(filesetIdent, subPath);
+      Assertions.assertEquals(
+          String.format("%s%s", mockFileset.storageLocation(), subPath.substring(1)), fileLocation);
+    }
+  }
+
   private static Stream<Arguments> locationArguments() {
     return Stream.of(
         // Honor the catalog location
