@@ -47,7 +47,7 @@ import org.apache.gravitino.exceptions.NoSuchSchemaException;
 import org.apache.gravitino.exceptions.SchemaAlreadyExistsException;
 import org.apache.gravitino.integration.test.container.ContainerSuite;
 import org.apache.gravitino.integration.test.container.DorisContainer;
-import org.apache.gravitino.integration.test.util.AbstractIT;
+import org.apache.gravitino.integration.test.util.BaseIT;
 import org.apache.gravitino.integration.test.util.GravitinoITUtils;
 import org.apache.gravitino.integration.test.util.ITUtils;
 import org.apache.gravitino.rel.Column;
@@ -78,13 +78,10 @@ import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInstance;
-import org.junit.jupiter.api.TestInstance.Lifecycle;
 import org.testcontainers.shaded.org.awaitility.Awaitility;
 
 @Tag("gravitino-docker-test")
-@TestInstance(Lifecycle.PER_CLASS)
-public class CatalogDorisIT extends AbstractIT {
+public class CatalogDorisIT extends BaseIT {
 
   private static final String provider = "jdbc-doris";
 
@@ -128,8 +125,8 @@ public class CatalogDorisIT extends AbstractIT {
   @AfterAll
   public void stop() {
     clearTableAndSchema();
-    metalake.dropCatalog(catalogName);
-    AbstractIT.client.dropMetalake(metalakeName);
+    metalake.dropCatalog(catalogName, true);
+    client.dropMetalake(metalakeName, true);
   }
 
   @AfterEach
@@ -143,13 +140,12 @@ public class CatalogDorisIT extends AbstractIT {
   }
 
   private void createMetalake() {
-    GravitinoMetalake[] gravitinoMetaLakes = AbstractIT.client.listMetalakes();
+    GravitinoMetalake[] gravitinoMetaLakes = client.listMetalakes();
     assertEquals(0, gravitinoMetaLakes.length);
 
-    GravitinoMetalake createdMetalake =
-        AbstractIT.client.createMetalake(metalakeName, "comment", Collections.emptyMap());
-    GravitinoMetalake loadMetalake = AbstractIT.client.loadMetalake(metalakeName);
-    assertEquals(createdMetalake, loadMetalake);
+    client.createMetalake(metalakeName, "comment", Collections.emptyMap());
+    GravitinoMetalake loadMetalake = client.loadMetalake(metalakeName);
+    assertEquals(metalakeName, loadMetalake.name());
 
     metalake = loadMetalake;
   }
@@ -334,25 +330,15 @@ public class CatalogDorisIT extends AbstractIT {
 
     Map<String, String> properties = createTableProperties();
     TableCatalog tableCatalog = catalog.asTableCatalog();
-    Table createdTable =
-        tableCatalog.createTable(
-            tableIdentifier,
-            columns,
-            table_comment,
-            properties,
-            Transforms.EMPTY_TRANSFORM,
-            distribution,
-            null,
-            indexes);
-
-    ITUtils.assertionsTableInfo(
-        tableName,
+    tableCatalog.createTable(
+        tableIdentifier,
+        columns,
         table_comment,
-        Arrays.asList(columns),
         properties,
-        indexes,
         Transforms.EMPTY_TRANSFORM,
-        createdTable);
+        distribution,
+        null,
+        indexes);
 
     // load table
     Table loadTable = tableCatalog.loadTable(tableIdentifier);
@@ -491,16 +477,16 @@ public class CatalogDorisIT extends AbstractIT {
 
     Map<String, String> properties = createTableProperties();
     TableCatalog tableCatalog = catalog.asTableCatalog();
-    Table createdTable =
-        tableCatalog.createTable(
-            tableIdentifier,
-            columns,
-            table_comment,
-            properties,
-            Transforms.EMPTY_TRANSFORM,
-            distribution,
-            null,
-            indexes);
+    tableCatalog.createTable(
+        tableIdentifier,
+        columns,
+        table_comment,
+        properties,
+        Transforms.EMPTY_TRANSFORM,
+        distribution,
+        null,
+        indexes);
+    Table loadedTable = tableCatalog.loadTable(tableIdentifier);
 
     ITUtils.assertionsTableInfo(
         tableName,
@@ -509,7 +495,7 @@ public class CatalogDorisIT extends AbstractIT {
         properties,
         indexes,
         Transforms.EMPTY_TRANSFORM,
-        createdTable);
+        loadedTable);
 
     // Alter column type
     tableCatalog.alterTable(
@@ -643,24 +629,15 @@ public class CatalogDorisIT extends AbstractIT {
     Map<String, String> properties = createTableProperties();
     Transform[] partitioning = {Transforms.list(new String[][] {{DORIS_COL_NAME1}})};
     TableCatalog tableCatalog = catalog.asTableCatalog();
-    Table createdTable =
-        tableCatalog.createTable(
-            tableIdentifier,
-            columns,
-            table_comment,
-            properties,
-            partitioning,
-            distribution,
-            null,
-            indexes);
-    ITUtils.assertionsTableInfo(
-        tableName,
+    tableCatalog.createTable(
+        tableIdentifier,
+        columns,
         table_comment,
-        Arrays.asList(columns),
         properties,
-        indexes,
         partitioning,
-        createdTable);
+        distribution,
+        null,
+        indexes);
 
     // load table
     Table loadTable = tableCatalog.loadTable(tableIdentifier);
@@ -874,24 +851,15 @@ public class CatalogDorisIT extends AbstractIT {
     Map<String, String> properties = createTableProperties();
     Transform[] partitioning = Transforms.EMPTY_TRANSFORM;
     TableCatalog tableCatalog = catalog.asTableCatalog();
-    Table createdTable =
-        tableCatalog.createTable(
-            tableIdentifier,
-            columns,
-            table_comment,
-            properties,
-            partitioning,
-            distribution,
-            null,
-            indexes);
-    ITUtils.assertionsTableInfo(
-        tableName,
+    tableCatalog.createTable(
+        tableIdentifier,
+        columns,
         table_comment,
-        Arrays.asList(columns),
         properties,
-        indexes,
         partitioning,
-        createdTable);
+        distribution,
+        null,
+        indexes);
 
     // load table
     Table loadTable = tableCatalog.loadTable(tableIdentifier);
