@@ -38,6 +38,7 @@ import org.apache.gravitino.catalog.jdbc.converter.JdbcTypeConverter;
 import org.apache.gravitino.catalog.jdbc.operation.JdbcTablePartitionOperations;
 import org.apache.gravitino.integration.test.util.GravitinoITUtils;
 import org.apache.gravitino.rel.TableChange;
+import org.apache.gravitino.rel.expressions.Expression;
 import org.apache.gravitino.rel.expressions.NamedReference;
 import org.apache.gravitino.rel.expressions.distributions.Distribution;
 import org.apache.gravitino.rel.expressions.distributions.Distributions;
@@ -94,6 +95,54 @@ public class TestDorisTableOperations extends TestDoris {
     return properties;
   }
 
+  @Test
+  void testAllDistribution() {
+    Distribution[] distributions =
+        new Distribution[] {
+          Distributions.even(DEFAULT_BUCKET_SIZE, Expression.EMPTY_EXPRESSION),
+          Distributions.hash(DEFAULT_BUCKET_SIZE, NamedReference.field("col_1")),
+          Distributions.even(10, Expression.EMPTY_EXPRESSION),
+          Distributions.hash(0, NamedReference.field("col_1")),
+          Distributions.hash(11, NamedReference.field("col_1")),
+          Distributions.hash(12, NamedReference.field("col_1"), NamedReference.field("col_2"))
+        };
+
+    for (Distribution distribution : distributions) {
+      String tableName = GravitinoITUtils.genRandomName("doris_basic_test_table");
+      String tableComment = "test_comment";
+      List<JdbcColumn> columns = new ArrayList<>();
+      JdbcColumn col_1 =
+          JdbcColumn.builder().withName("col_1").withType(INT).withComment("id").build();
+      columns.add(col_1);
+      JdbcColumn col_2 =
+          JdbcColumn.builder().withName("col_2").withType(VARCHAR_255).withComment("col_2").build();
+      columns.add(col_2);
+      JdbcColumn col_3 =
+          JdbcColumn.builder().withName("col_3").withType(VARCHAR_255).withComment("col_3").build();
+      columns.add(col_3);
+      Map<String, String> properties = new HashMap<>();
+      Index[] indexes = new Index[] {};
+
+      // create table
+      TABLE_OPERATIONS.create(
+          databaseName,
+          tableName,
+          columns.toArray(new JdbcColumn[0]),
+          tableComment,
+          createProperties(),
+          null,
+          distribution,
+          indexes);
+      JdbcTable load = TABLE_OPERATIONS.load(databaseName, tableName);
+      assertionsTableInfo(
+          tableName, tableComment, columns, properties, indexes, Transforms.EMPTY_TRANSFORM, load);
+
+      Assertions.assertEquals(distribution.strategy(), load.distribution().strategy());
+      Assertions.assertArrayEquals(distribution.expressions(), load.distribution().expressions());
+      TABLE_OPERATIONS.drop(databaseName, tableName);
+    }
+  }
+
   @Test
   public void testBasicTableOperation() {
     String tableName = GravitinoITUtils.genRandomName("doris_basic_test_table");
