@@ -37,7 +37,7 @@ import org.apache.gravitino.Catalog;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.SchemaChange;
-import org.apache.gravitino.catalog.lakehouse.iceberg.ops.IcebergTableOpsHelper;
+import org.apache.gravitino.catalog.lakehouse.iceberg.ops.IcebergCatalogWrapperHelper;
 import org.apache.gravitino.connector.CatalogInfo;
 import org.apache.gravitino.connector.CatalogOperations;
 import org.apache.gravitino.connector.HasPropertyMetadata;
@@ -50,8 +50,8 @@ import org.apache.gravitino.exceptions.NonEmptySchemaException;
 import org.apache.gravitino.exceptions.SchemaAlreadyExistsException;
 import org.apache.gravitino.exceptions.TableAlreadyExistsException;
 import org.apache.gravitino.iceberg.common.IcebergConfig;
-import org.apache.gravitino.iceberg.common.ops.IcebergTableOps;
-import org.apache.gravitino.iceberg.common.ops.IcebergTableOps.IcebergTableChange;
+import org.apache.gravitino.iceberg.common.ops.IcebergCatalogWrapper;
+import org.apache.gravitino.iceberg.common.ops.IcebergCatalogWrapper.IcebergTableChange;
 import org.apache.gravitino.meta.AuditInfo;
 import org.apache.gravitino.rel.Column;
 import org.apache.gravitino.rel.Table;
@@ -62,6 +62,7 @@ import org.apache.gravitino.rel.expressions.sorts.SortOrder;
 import org.apache.gravitino.rel.expressions.transforms.Transform;
 import org.apache.gravitino.rel.indexes.Index;
 import org.apache.gravitino.utils.MapUtils;
+import org.apache.gravitino.utils.PrincipalUtils;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
 import org.apache.iceberg.exceptions.NamespaceNotEmptyException;
@@ -82,9 +83,9 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
 
   public static final Logger LOG = LoggerFactory.getLogger(IcebergCatalogOperations.class);
 
-  @VisibleForTesting IcebergTableOps icebergTableOps;
+  @VisibleForTesting IcebergCatalogWrapper icebergCatalogWrapper;
 
-  private IcebergTableOpsHelper icebergTableOpsHelper;
+  private IcebergCatalogWrapperHelper icebergCatalogWrapperHelper;
 
   /**
    * Initializes the Iceberg catalog operations with the provided configuration.
@@ -110,16 +111,17 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
     resultConf.put("catalog_uuid", info.id().toString());
     IcebergConfig icebergConfig = new IcebergConfig(resultConf);
 
-    this.icebergTableOps = new IcebergTableOps(icebergConfig);
-    this.icebergTableOpsHelper = new IcebergTableOpsHelper(icebergTableOps.getCatalog());
+    this.icebergCatalogWrapper = new IcebergCatalogWrapper(icebergConfig);
+    this.icebergCatalogWrapperHelper =
+        new IcebergCatalogWrapperHelper(icebergCatalogWrapper.getCatalog());
   }
 
   /** Closes the Iceberg catalog and releases the associated client pool. */
   @Override
   public void close() {
-    if (null != icebergTableOps) {
+    if (null != icebergCatalogWrapper) {
       try {
-        icebergTableOps.close();
+        icebergCatalogWrapper.close();
       } catch (Exception e) {
         LOG.warn("Failed to close Iceberg catalog", e);
       }
@@ -137,7 +139,9 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
   public NameIdentifier[] listSchemas(Namespace namespace) throws NoSuchCatalogException {
     try {
       List<org.apache.iceberg.catalog.Namespace> namespaces =
-          icebergTableOps.listNamespace(IcebergTableOpsHelper.getIcebergNamespace()).namespaces();
+          icebergCatalogWrapper
+              .listNamespace(IcebergCatalogWrapperHelper.getIcebergNamespace())
+              .namespaces();
 
       return namespaces.stream()
           .map(icebergNamespace -> NameIdentifier.of(namespace, icebergNamespace.toString()))
@@ -175,8 +179,9 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
                       .withCreateTime(Instant.now())
                       .build())
               .build();
-      icebergTableOps.createNamespace(
-          createdSchema.toCreateRequest(IcebergTableOpsHelper.getIcebergNamespace(ident.name())));
+      icebergCatalogWrapper.createNamespace(
+          createdSchema.toCreateRequest(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(ident.name())));
       LOG.info(
           "Created Iceberg schema (database) {} in Iceberg\ncurrentUser:{} \ncomment: {} \nmetadata: {}",
           ident.name(),
@@ -208,7 +213,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
   public IcebergSchema loadSchema(NameIdentifier ident) throws NoSuchSchemaException {
     try {
       GetNamespaceResponse response =
-          icebergTableOps.loadNamespace(IcebergTableOpsHelper.getIcebergNamespace(ident.name()));
+          icebergCatalogWrapper.loadNamespace(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(ident.name()));
       IcebergSchema icebergSchema =
           IcebergSchema.builder()
               .withName(ident.name())
@@ -241,7 +247,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
       throws NoSuchSchemaException {
     try {
       GetNamespaceResponse response =
-          icebergTableOps.loadNamespace(IcebergTableOpsHelper.getIcebergNamespace(ident.name()));
+          icebergCatalogWrapper.loadNamespace(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(ident.name()));
       Map<String, String> metadata = response.properties();
       List<String> removals = new ArrayList<>();
       Map<String, String> updates = new HashMap<>();
@@ -275,8 +282,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
       UpdateNamespacePropertiesRequest updateNamespacePropertiesRequest =
           UpdateNamespacePropertiesRequest.builder().updateAll(updates).removeAll(removals).build();
       UpdateNamespacePropertiesResponse updateNamespacePropertiesResponse =
-          icebergTableOps.updateNamespaceProperties(
-              IcebergTableOpsHelper.getIcebergNamespace(ident.name()),
+          icebergCatalogWrapper.updateNamespaceProperties(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(ident.name()),
               updateNamespacePropertiesRequest);
       LOG.info(
           "Altered Iceberg schema (database) {}. UpdateResponse:\n{}",
@@ -303,7 +310,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
   public boolean dropSchema(NameIdentifier ident, boolean cascade) throws NonEmptySchemaException {
     Preconditions.checkArgument(!cascade, "Iceberg does not support cascading delete operations.");
     try {
-      icebergTableOps.dropNamespace(IcebergTableOpsHelper.getIcebergNamespace(ident.name()));
+      icebergCatalogWrapper.dropNamespace(
+          IcebergCatalogWrapperHelper.getIcebergNamespace(ident.name()));
       LOG.info("Dropped Iceberg schema (database) {}", ident.name());
       return true;
     } catch (NamespaceNotEmptyException e) {
@@ -333,7 +341,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
 
     try {
       ListTablesResponse listTablesResponse =
-          icebergTableOps.listTable(IcebergTableOpsHelper.getIcebergNamespace(namespace));
+          icebergCatalogWrapper.listTable(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(namespace));
       return listTablesResponse.identifiers().stream()
           .map(
               tableIdentifier ->
@@ -356,7 +365,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
     try {
 
       LoadTableResponse tableResponse =
-          icebergTableOps.loadTable(IcebergTableOpsHelper.buildIcebergTableIdentifier(tableIdent));
+          icebergCatalogWrapper.loadTable(
+              IcebergCatalogWrapperHelper.buildIcebergTableIdentifier(tableIdent));
       IcebergTable icebergTable =
           IcebergTable.fromIcebergTable(tableResponse.tableMetadata(), tableIdent.name());
 
@@ -405,9 +415,9 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
     try {
       String[] levels = tableIdent.namespace().levels();
       IcebergTableChange icebergTableChange =
-          icebergTableOpsHelper.buildIcebergTableChanges(
+          icebergCatalogWrapperHelper.buildIcebergTableChanges(
               NameIdentifier.of(levels[levels.length - 1], tableIdent.name()), changes);
-      LoadTableResponse loadTableResponse = icebergTableOps.updateTable(icebergTableChange);
+      LoadTableResponse loadTableResponse = icebergCatalogWrapper.updateTable(icebergTableChange);
       loadTableResponse.validate();
       return IcebergTable.fromIcebergTable(loadTableResponse.tableMetadata(), tableIdent.name());
     } catch (org.apache.iceberg.exceptions.NoSuchTableException e) {
@@ -429,12 +439,12 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
     try {
       RenameTableRequest renameTableRequest =
           RenameTableRequest.builder()
-              .withSource(IcebergTableOpsHelper.buildIcebergTableIdentifier(tableIdent))
+              .withSource(IcebergCatalogWrapperHelper.buildIcebergTableIdentifier(tableIdent))
               .withDestination(
-                  IcebergTableOpsHelper.buildIcebergTableIdentifier(
+                  IcebergCatalogWrapperHelper.buildIcebergTableIdentifier(
                       tableIdent.namespace(), renameTable.getNewName()))
               .build();
-      icebergTableOps.renameTable(renameTableRequest);
+      icebergCatalogWrapper.renameTable(renameTableRequest);
       return loadTable(NameIdentifier.of(tableIdent.namespace(), renameTable.getNewName()));
     } catch (org.apache.iceberg.exceptions.NoSuchTableException e) {
       throw new NoSuchTableException(e, ICEBERG_TABLE_DOES_NOT_EXIST_MSG, tableIdent.name());
@@ -450,7 +460,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
   @Override
   public boolean dropTable(NameIdentifier tableIdent) {
     try {
-      icebergTableOps.dropTable(IcebergTableOpsHelper.buildIcebergTableIdentifier(tableIdent));
+      icebergCatalogWrapper.dropTable(
+          IcebergCatalogWrapperHelper.buildIcebergTableIdentifier(tableIdent));
       LOG.info("Dropped Iceberg table {}", tableIdent.name());
       return true;
     } catch (org.apache.iceberg.exceptions.NoSuchTableException e) {
@@ -519,8 +530,8 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
               .build();
 
       LoadTableResponse loadTableResponse =
-          icebergTableOps.createTable(
-              IcebergTableOpsHelper.getIcebergNamespace(schemaIdent.name()),
+          icebergCatalogWrapper.createTable(
+              IcebergCatalogWrapperHelper.getIcebergNamespace(schemaIdent.name()),
               createdTable.toCreateTableRequest());
       loadTableResponse.validate();
 
@@ -542,7 +553,7 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
   public boolean purgeTable(NameIdentifier tableIdent) throws UnsupportedOperationException {
     try {
       String schema = NameIdentifier.of(tableIdent.namespace().levels()).name();
-      icebergTableOps.purgeTable(TableIdentifier.of(schema, tableIdent.name()));
+      icebergCatalogWrapper.purgeTable(TableIdentifier.of(schema, tableIdent.name()));
       LOG.info("Purge Iceberg table {}", tableIdent.name());
       return true;
     } catch (org.apache.iceberg.exceptions.NoSuchTableException e) {
@@ -570,15 +581,14 @@ public class IcebergCatalogOperations implements CatalogOperations, SupportsSche
       String comment,
       Map<String, String> properties) {
     try {
-      icebergTableOps.listNamespace(IcebergTableOpsHelper.getIcebergNamespace());
+      icebergCatalogWrapper.listNamespace(IcebergCatalogWrapperHelper.getIcebergNamespace());
     } catch (Exception e) {
       throw new ConnectionFailedException(
           e, "Failed to run listNamespace on Iceberg catalog: %s", e.getMessage());
     }
   }
 
-  // TODO. We should figure out a better way to get the current user from servlet container.
   private static String currentUser() {
-    return System.getProperty("user.name");
+    return PrincipalUtils.getCurrentUserName();
   }
 }
