@@ -23,6 +23,8 @@ import java.io.File;
 import java.util.Collections;
 import java.util.List;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.gravitino.audit.FileAuditWriter;
+import org.apache.gravitino.audit.SimpleFormatter;
 import org.apache.gravitino.config.ConfigBuilder;
 import org.apache.gravitino.config.ConfigConstants;
 import org.apache.gravitino.config.ConfigEntry;
@@ -342,4 +344,27 @@ public class Configs {
           .stringConf()
           .toSequence()
           .createWithDefault(Collections.emptyList());
+
+  public static final String AUDIT_LOG_WRITER_CONFIG_PREFIX = "gravitino.audit.writer.";
+
+  public static final ConfigEntry<Boolean> AUDIT_LOG_ENABLED_CONF =
+      new ConfigBuilder("gravitino.audit.enabled")
+          .doc("Gravitino audit log enable flag")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .booleanConf()
+          .createWithDefault(false);
+
+  public static final ConfigEntry<String> AUDIT_LOG_WRITER_CLASS_NAME =
+      new ConfigBuilder("gravitino.audit.writer.className")
+          .doc("Gravitino audit log writer class name")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .createWithDefault(FileAuditWriter.class.getName());
+
+  public static final ConfigEntry<String> AUDIT_LOG_FORMATTER_CLASS_NAME =
+      new ConfigBuilder("gravitino.audit.formatter.className")
+          .doc("Gravitino event log formatter class name")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .createWithDefault(SimpleFormatter.class.getName());
 }
