@@ -19,14 +19,12 @@
 package org.apache.gravitino.authorization;
 
 import com.google.common.collect.Sets;
-import java.io.IOException;
 import java.util.Collection;
 import java.util.List;
 import java.util.Set;
 import java.util.function.Consumer;
 import org.apache.gravitino.Catalog;
 import org.apache.gravitino.Entity;
-import org.apache.gravitino.EntityStore;
 import org.apache.gravitino.GravitinoEnv;
 import org.apache.gravitino.MetadataObject;
 import org.apache.gravitino.NameIdentifier;
@@ -36,23 +34,20 @@ import org.apache.gravitino.connector.BaseCatalog;
 import org.apache.gravitino.connector.authorization.AuthorizationPlugin;
 import org.apache.gravitino.dto.authorization.PrivilegeDTO;
 import org.apache.gravitino.dto.util.DTOConverters;
+import org.apache.gravitino.exceptions.ForbiddenException;
 import org.apache.gravitino.exceptions.IllegalPrivilegeException;
 import org.apache.gravitino.exceptions.NoSuchCatalogException;
 import org.apache.gravitino.exceptions.NoSuchMetadataObjectException;
-import org.apache.gravitino.exceptions.NoSuchMetalakeException;
+import org.apache.gravitino.exceptions.NoSuchUserException;
 import org.apache.gravitino.utils.MetadataObjectUtil;
 import org.apache.gravitino.utils.NameIdentifierUtil;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 /* The utilization class of authorization module*/
 public class AuthorizationUtils {
 
-  static final String USER_DOES_NOT_EXIST_MSG = "User %s does not exist in th metalake %s";
-  static final String GROUP_DOES_NOT_EXIST_MSG = "Group %s does not exist in th metalake %s";
-  static final String ROLE_DOES_NOT_EXIST_MSG = "Role %s does not exist in th metalake %s";
-  private static final Logger LOG = LoggerFactory.getLogger(AuthorizationUtils.class);
-  private static final String METALAKE_DOES_NOT_EXIST_MSG = "Metalake %s does not exist";
+  static final String USER_DOES_NOT_EXIST_MSG = "User %s does not exist in the metalake %s";
+  static final String GROUP_DOES_NOT_EXIST_MSG = "Group %s does not exist in the metalake %s";
+  static final String ROLE_DOES_NOT_EXIST_MSG = "Role %s does not exist in the metalake %s";
 
   private static final Set<Privilege.Name> FILESET_PRIVILEGES =
       Sets.immutableEnumSet(
@@ -66,18 +61,17 @@ public class AuthorizationUtils {
 
   private AuthorizationUtils() {}
 
-  static void checkMetalakeExists(String metalake) throws NoSuchMetalakeException {
+  public static void checkCurrentUser(String metalake, String user) {
     try {
-      EntityStore store = GravitinoEnv.getInstance().entityStore();
-
-      NameIdentifier metalakeIdent = NameIdentifier.of(metalake);
-      if (!store.exists(metalakeIdent, Entity.EntityType.METALAKE)) {
-        LOG.warn("Metalake {} does not exist", metalakeIdent);
-        throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, metalakeIdent);
+      AccessControlDispatcher dispatcher = GravitinoEnv.getInstance().accessControlDispatcher();
+      // Only when we enable authorization, we need to check the current user
+      if (dispatcher != null) {
+        dispatcher.getUser(metalake, user);
       }
-    } catch (IOException e) {
-      LOG.error("Failed to do storage operation", e);
-      throw new RuntimeException(e);
+    } catch (NoSuchUserException nsu) {
+      throw new ForbiddenException(
+          "Current user %s doesn't exist in the metalake %s, you should add the user to the metalake first",
+          user, metalake);
     }
   }
 
@@ -155,9 +149,11 @@ public class AuthorizationUtils {
     CatalogManager catalogManager = GravitinoEnv.getInstance().catalogManager();
     for (SecurableObject securableObject : securableObjects) {
       if (needApplyAuthorizationPluginAllCatalogs(securableObject)) {
-        Catalog[] catalogs = catalogManager.listCatalogsInfo(Namespace.of(metalake));
-        for (Catalog catalog : catalogs) {
-          callAuthorizationPluginImpl(consumer, catalog);
+        NameIdentifier[] catalogs = catalogManager.listCatalogs(Namespace.of(metalake));
+        // ListCatalogsInfo return `CatalogInfo` instead of `BaseCatalog`, we need `BaseCatalog` to
+        // call authorization plugin method.
+        for (NameIdentifier catalog : catalogs) {
+          callAuthorizationPluginImpl(consumer, catalogManager.loadCatalog(catalog));
         }
 
       } else if (needApplyAuthorization(securableObject.type())) {
@@ -190,17 +186,6 @@ public class AuthorizationUtils {
     }
   }
 
-  private static void callAuthorizationPluginImpl(
-      Consumer<AuthorizationPlugin> consumer, Catalog catalog) {
-
-    if (catalog instanceof BaseCatalog) {
-      BaseCatalog baseCatalog = (BaseCatalog) catalog;
-      if (baseCatalog.getAuthorizationPlugin() != null) {
-        consumer.accept(baseCatalog.getAuthorizationPlugin());
-      }
-    }
-  }
-
   public static boolean needApplyAuthorizationPluginAllCatalogs(SecurableObject securableObject) {
     if (securableObject.type() == MetadataObject.Type.METALAKE) {
       List<Privilege> privileges = securableObject.privileges();
@@ -275,4 +260,50 @@ public class AuthorizationUtils {
   private static boolean needApplyAuthorization(MetadataObject.Type type) {
     return type != MetadataObject.Type.ROLE && type != MetadataObject.Type.METALAKE;
   }
+
+  private static void callAuthorizationPluginImpl(
+      Consumer<AuthorizationPlugin> consumer, Catalog catalog) {
+
+    if (catalog instanceof BaseCatalog) {
+      BaseCatalog baseCatalog = (BaseCatalog) catalog;
+      if (baseCatalog.getAuthorizationPlugin() != null) {
+        consumer.accept(baseCatalog.getAuthorizationPlugin());
+      }
+    }
+  }
+
+  public static void authorizationPluginRemovePrivileges(
+      NameIdentifier ident, Entity.EntityType type) {
+    // If we enable authorization, we should remove the privileges about the entity in the
+    // authorization plugin.
+    if (GravitinoEnv.getInstance().accessControlDispatcher() != null) {
+      MetadataObject metadataObject = NameIdentifierUtil.toMetadataObject(ident, type);
+      MetadataObjectChange removeObject = MetadataObjectChange.remove(metadataObject);
+      callAuthorizationPluginForMetadataObject(
+          ident.namespace().level(0),
+          metadataObject,
+          authorizationPlugin -> {
+            authorizationPlugin.onMetadataUpdated(removeObject);
+          });
+    }
+  }
+
+  public static void authorizationPluginRenamePrivileges(
+      NameIdentifier ident, Entity.EntityType type, String newName) {
+    // If we enable authorization, we should rename the privileges about the entity in the
+    // authorization plugin.
+    if (GravitinoEnv.getInstance().accessControlDispatcher() != null) {
+      MetadataObject oldMetadataObject = NameIdentifierUtil.toMetadataObject(ident, type);
+      MetadataObject newMetadataObject =
+          NameIdentifierUtil.toMetadataObject(NameIdentifier.of(ident.namespace(), newName), type);
+      MetadataObjectChange renameObject =
+          MetadataObjectChange.rename(oldMetadataObject, newMetadataObject);
+      callAuthorizationPluginForMetadataObject(
+          ident.namespace().level(0),
+          oldMetadataObject,
+          authorizationPlugin -> {
+            authorizationPlugin.onMetadataUpdated(renameObject);
+          });
+    }
+  }
 }
