@@ -111,7 +111,9 @@ public class SchemaOperationDispatcher extends OperationDispatcher implements Sc
     Map<String, String> updatedProperties =
         StringIdentifier.newPropertiesWithId(stringId, properties);
 
-    Schema createdSchema =
+    // we do not retrieve the schema again (to obtain some values generated by underlying catalog)
+    // since some catalogs' API is async and the schema may not be created immediately
+    Schema schema =
         doWithCatalog(
             catalogIdent,
             c -> c.doWithSchemaOps(s -> s.createSchema(ident, comment, updatedProperties)),
@@ -121,21 +123,14 @@ public class SchemaOperationDispatcher extends OperationDispatcher implements Sc
     // If the Schema is maintained by the Gravitino's store, we don't have to store again.
     boolean isManagedSchema = isManagedEntity(catalogIdent, Capability.Scope.SCHEMA);
     if (isManagedSchema) {
-      return EntityCombinedSchema.of(createdSchema)
+      return EntityCombinedSchema.of(schema)
           .withHiddenPropertiesSet(
               getHiddenPropertyNames(
                   catalogIdent,
                   HasPropertyMetadata::schemaPropertiesMetadata,
-                  createdSchema.properties()));
+                  schema.properties()));
     }
 
-    // Retrieve the Schema again to obtain some values generated by underlying catalog
-    Schema schema =
-        doWithCatalog(
-            catalogIdent,
-            c -> c.doWithSchemaOps(s -> s.loadSchema(ident)),
-            NoSuchSchemaException.class);
-
     SchemaEntity schemaEntity =
         SchemaEntity.builder()
             .withId(uid)
@@ -208,21 +203,10 @@ public class SchemaOperationDispatcher extends OperationDispatcher implements Sc
     validateAlterProperties(ident, HasPropertyMetadata::schemaPropertiesMetadata, changes);
 
     NameIdentifier catalogIdent = getCatalogIdentifier(ident);
-    Schema tempAlteredSchema =
-        doWithCatalog(
-            catalogIdent,
-            c -> c.doWithSchemaOps(s -> s.alterSchema(ident, changes)),
-            NoSuchSchemaException.class);
-
-    // Retrieve the Schema again to obtain some values generated by underlying catalog
     Schema alteredSchema =
         doWithCatalog(
             catalogIdent,
-            c ->
-                c.doWithSchemaOps(
-                    s ->
-                        s.loadSchema(
-                            NameIdentifier.of(ident.namespace(), tempAlteredSchema.name()))),
+            c -> c.doWithSchemaOps(s -> s.alterSchema(ident, changes)),
             NoSuchSchemaException.class);
 
     // If the Schema is maintained by the Gravitino's store, we don't have to alter again.
