@@ -24,9 +24,17 @@ import static org.apache.gravitino.catalog.PropertiesMetadataHelpers.validatePro
 import static org.apache.gravitino.rel.expressions.transforms.Transforms.EMPTY_TRANSFORM;
 import static org.apache.gravitino.utils.NameIdentifierUtil.getCatalogIdentifier;
 
+import com.google.common.base.Objects;
+import com.google.common.collect.Lists;
 import java.time.Instant;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
 import java.util.Map;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+import java.util.stream.IntStream;
+import org.apache.commons.lang3.tuple.Pair;
 import org.apache.gravitino.EntityStore;
 import org.apache.gravitino.GravitinoEnv;
 import org.apache.gravitino.NameIdentifier;
@@ -41,6 +49,7 @@ import org.apache.gravitino.exceptions.TableAlreadyExistsException;
 import org.apache.gravitino.lock.LockType;
 import org.apache.gravitino.lock.TreeLockUtils;
 import org.apache.gravitino.meta.AuditInfo;
+import org.apache.gravitino.meta.ColumnEntity;
 import org.apache.gravitino.meta.TableEntity;
 import org.apache.gravitino.rel.Column;
 import org.apache.gravitino.rel.Table;
@@ -97,26 +106,31 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
    */
   @Override
   public Table loadTable(NameIdentifier ident) throws NoSuchTableException {
-    EntityCombinedTable table =
+    EntityCombinedTable entityCombinedTable =
         TreeLockUtils.doWithTreeLock(ident, LockType.READ, () -> internalLoadTable(ident));
 
-    if (!table.imported()) {
+    if (!entityCombinedTable.imported()) {
       // Load the schema to make sure the schema is imported.
       SchemaDispatcher schemaDispatcher = GravitinoEnv.getInstance().schemaDispatcher();
       NameIdentifier schemaIdent = NameIdentifier.of(ident.namespace().levels());
       schemaDispatcher.loadSchema(schemaIdent);
 
       // Import the table.
-      TreeLockUtils.doWithTreeLock(
-          schemaIdent,
-          LockType.WRITE,
-          () -> {
-            importTable(ident);
-            return null;
-          });
+      entityCombinedTable =
+          TreeLockUtils.doWithTreeLock(schemaIdent, LockType.WRITE, () -> importTable(ident));
     }
 
-    return table;
+    // Update the column entities in Gravitino store if the columns are different from the ones
+    // fetching from the underlying source.
+    TableEntity updatedEntity = updateColumnsIfNecessaryWhenLoad(ident, entityCombinedTable);
+
+    return EntityCombinedTable.of(entityCombinedTable.tableFromCatalog(), updatedEntity)
+        .withHiddenPropertiesSet(
+            getHiddenPropertyNames(
+                getCatalogIdentifier(ident),
+                HasPropertyMetadata::tablePropertiesMetadata,
+                entityCombinedTable.tableFromCatalog().properties()))
+        .withImported(entityCombinedTable.imported());
   }
 
   /**
@@ -180,7 +194,7 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
     validateAlterProperties(ident, HasPropertyMetadata::tablePropertiesMetadata, changes);
 
     NameIdentifier catalogIdent = getCatalogIdentifier(ident);
-    Table tempAlteredTable =
+    Table alteredTable =
         doWithCatalog(
             catalogIdent,
             c ->
@@ -189,16 +203,6 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
             NoSuchTableException.class,
             IllegalArgumentException.class);
 
-    // Retrieve the Table again to obtain some values generated by underlying catalog
-    Table alteredTable =
-        doWithCatalog(
-            catalogIdent,
-            c ->
-                c.doWithTableOps(
-                    t ->
-                        t.loadTable(NameIdentifier.of(ident.namespace(), tempAlteredTable.name()))),
-            NoSuchTableException.class);
-
     StringIdentifier stringId = getStringIdFromProperties(alteredTable.properties());
     // Case 1: The table is not created by Gravitino.
     if (stringId == null) {
@@ -225,11 +229,15 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                               .map(c -> ((TableChange.RenameTable) c).getNewName())
                               .reduce((c1, c2) -> c2)
                               .orElse(tableEntity.name());
+                      // Update the columns
+                      Pair<Boolean, List<ColumnEntity>> columnsUpdateResult =
+                          updateColumnsIfNecessary(alteredTable, tableEntity);
 
                       return TableEntity.builder()
                           .withId(tableEntity.id())
                           .withName(newName)
                           .withNamespace(ident.namespace())
+                          .withColumns(columnsUpdateResult.getRight())
                           .withAuditInfo(
                               AuditInfo.builder()
                                   .withCreator(tableEntity.auditInfo().creator())
@@ -338,11 +346,11 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
         : droppedFromCatalog;
   }
 
-  private void importTable(NameIdentifier identifier) {
+  private EntityCombinedTable importTable(NameIdentifier identifier) {
     EntityCombinedTable table = internalLoadTable(identifier);
 
     if (table.imported()) {
-      return;
+      return table;
     }
 
     StringIdentifier stringId = null;
@@ -358,8 +366,8 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
       // of external system to correct it.
       LOG.warn(
           "The Table uid {} existed but still need to be imported, this could be happened "
-              + "when Table is renamed by external systems not controlled by Gravitino. In this case, "
-              + "we need to overwrite the stored entity to keep the consistency.",
+              + "when Table is renamed by external systems not controlled by Gravitino. In this "
+              + "case, we need to overwrite the stored entity to keep the consistency.",
           stringId);
       uid = stringId.id();
     } else {
@@ -367,18 +375,22 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
       uid = idGenerator.nextId();
     }
 
+    AuditInfo audit =
+        AuditInfo.builder()
+            .withCreator(table.auditInfo().creator())
+            .withCreateTime(table.auditInfo().createTime())
+            .withLastModifier(table.auditInfo().lastModifier())
+            .withLastModifiedTime(table.auditInfo().lastModifiedTime())
+            .build();
+    List<ColumnEntity> columnEntityList =
+        toColumnEntities(table.tableFromCatalog().columns(), audit);
     TableEntity tableEntity =
         TableEntity.builder()
             .withId(uid)
             .withName(identifier.name())
             .withNamespace(identifier.namespace())
-            .withAuditInfo(
-                AuditInfo.builder()
-                    .withCreator(table.auditInfo().creator())
-                    .withCreateTime(table.auditInfo().createTime())
-                    .withLastModifier(table.auditInfo().lastModifier())
-                    .withLastModifiedTime(table.auditInfo().lastModifiedTime())
-                    .build())
+            .withColumns(columnEntityList)
+            .withAuditInfo(audit)
             .build();
     try {
       store.put(tableEntity, true);
@@ -386,6 +398,13 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
       LOG.error(FormattedErrorMessages.STORE_OP_FAILURE, "put", identifier, e);
       throw new RuntimeException("Fail to import the table entity to the store.", e);
     }
+
+    return EntityCombinedTable.of(table.tableFromCatalog(), tableEntity)
+        .withHiddenPropertiesSet(
+            getHiddenPropertyNames(
+                getCatalogIdentifier(identifier),
+                HasPropertyMetadata::tablePropertiesMetadata,
+                table.tableFromCatalog().properties()));
   }
 
   private EntityCombinedTable internalLoadTable(NameIdentifier ident) {
@@ -455,42 +474,45 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
     Map<String, String> updatedProperties =
         StringIdentifier.newPropertiesWithId(stringId, properties);
 
-    doWithCatalog(
-        catalogIdent,
-        c ->
-            c.doWithTableOps(
-                t ->
-                    t.createTable(
-                        ident,
-                        columns,
-                        comment,
-                        updatedProperties,
-                        partitions == null ? EMPTY_TRANSFORM : partitions,
-                        distribution == null ? Distributions.NONE : distribution,
-                        sortOrders == null ? new SortOrder[0] : sortOrders,
-                        indexes == null ? Indexes.EMPTY_INDEXES : indexes)),
-        NoSuchSchemaException.class,
-        TableAlreadyExistsException.class);
+    // we do not retrieve the table again (to obtain some values generated by underlying catalog)
+    // since some catalogs' API is async and the table may not be created immediately
+    Table table =
+        doWithCatalog(
+            catalogIdent,
+            c ->
+                c.doWithTableOps(
+                    t ->
+                        t.createTable(
+                            ident,
+                            columns,
+                            comment,
+                            updatedProperties,
+                            partitions == null ? EMPTY_TRANSFORM : partitions,
+                            distribution == null ? Distributions.NONE : distribution,
+                            sortOrders == null ? new SortOrder[0] : sortOrders,
+                            indexes == null ? Indexes.EMPTY_INDEXES : indexes)),
+            NoSuchSchemaException.class,
+            TableAlreadyExistsException.class);
+
+    AuditInfo audit =
+        AuditInfo.builder()
+            .withCreator(PrincipalUtils.getCurrentPrincipal().getName())
+            .withCreateTime(Instant.now())
+            .build();
+    List<ColumnEntity> columnEntityList =
+        IntStream.range(0, columns.length)
+            .mapToObj(i -> ColumnEntity.toColumnEntity(columns[i], i, idGenerator.nextId(), audit))
+            .collect(Collectors.toList());
 
     TableEntity tableEntity =
         TableEntity.builder()
             .withId(uid)
             .withName(ident.name())
             .withNamespace(ident.namespace())
-            .withAuditInfo(
-                AuditInfo.builder()
-                    .withCreator(PrincipalUtils.getCurrentPrincipal().getName())
-                    .withCreateTime(Instant.now())
-                    .build())
+            .withColumns(columnEntityList)
+            .withAuditInfo(audit)
             .build();
 
-    // Retrieve the Table again to obtain some values generated by underlying catalog
-    Table table =
-        doWithCatalog(
-            catalogIdent,
-            c -> c.doWithTableOps(t -> t.loadTable(ident)),
-            NoSuchTableException.class);
-
     try {
       store.put(tableEntity, true /* overwrite */);
     } catch (Exception e) {
@@ -506,4 +528,158 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
             getHiddenPropertyNames(
                 catalogIdent, HasPropertyMetadata::tablePropertiesMetadata, table.properties()));
   }
+
+  private List<ColumnEntity> toColumnEntities(Column[] columns, AuditInfo audit) {
+    return columns == null
+        ? Collections.emptyList()
+        : IntStream.range(0, columns.length)
+            .mapToObj(i -> ColumnEntity.toColumnEntity(columns[i], i, idGenerator.nextId(), audit))
+            .collect(Collectors.toList());
+  }
+
+  private boolean isSameColumn(Column left, int columnPosition, ColumnEntity right) {
+    return Objects.equal(left.name(), right.name())
+        && columnPosition == right.position()
+        && Objects.equal(left.dataType(), right.dataType())
+        && Objects.equal(left.comment(), right.comment())
+        && left.nullable() == right.nullable()
+        && left.autoIncrement() == right.autoIncrement()
+        && Objects.equal(left.defaultValue(), right.defaultValue());
+  }
+
+  private Pair<Boolean, List<ColumnEntity>> updateColumnsIfNecessary(
+      Table tableFromCatalog, TableEntity tableFromGravitino) {
+    if (tableFromCatalog == null || tableFromGravitino == null) {
+      LOG.warn(
+          "Cannot update columns for table when altering because table or table entity is "
+              + "null");
+      return Pair.of(false, Collections.emptyList());
+    }
+
+    Map<String, Pair<Integer, Column>> columnsFromCatalogTable =
+        tableFromCatalog.columns() == null
+            ? Collections.emptyMap()
+            : IntStream.range(0, tableFromCatalog.columns().length)
+                .mapToObj(i -> Pair.of(i, tableFromCatalog.columns()[i]))
+                .collect(Collectors.toMap(p -> p.getRight().name(), Function.identity()));
+    Map<String, ColumnEntity> columnsFromTableEntity =
+        tableFromGravitino.columns() == null
+            ? Collections.emptyMap()
+            : tableFromGravitino.columns().stream()
+                .collect(Collectors.toMap(ColumnEntity::name, Function.identity()));
+
+    // Check if columns need to be updated in Gravitino store
+    List<ColumnEntity> columnsToInsert = Lists.newArrayList();
+    boolean columnsNeedsUpdate = false;
+    for (Map.Entry<String, ColumnEntity> entry : columnsFromTableEntity.entrySet()) {
+      Pair<Integer, Column> columnPair = columnsFromCatalogTable.get(entry.getKey());
+      if (columnPair == null) {
+        LOG.debug(
+            "Column {} is not found in the table from underlying source, it will be removed"
+                + " from the table entity",
+            entry.getKey());
+        columnsNeedsUpdate = true;
+
+      } else if (!isSameColumn(columnPair.getRight(), columnPair.getLeft(), entry.getValue())) {
+        // If the column need to be updated, we create a new ColumnEntity with the same id
+        LOG.debug(
+            "Column {} is found in the table from underlying source, but it is different "
+                + "from the one in the table entity, it will be updated",
+            entry.getKey());
+
+        Column column = columnPair.getRight();
+        ColumnEntity updatedColumnEntity =
+            ColumnEntity.builder()
+                .withId(entry.getValue().id())
+                .withName(column.name())
+                .withPosition(columnPair.getLeft())
+                .withDataType(column.dataType())
+                .withComment(column.comment())
+                .withNullable(column.nullable())
+                .withAutoIncrement(column.autoIncrement())
+                .withDefaultValue(column.defaultValue())
+                .withAuditInfo(
+                    AuditInfo.builder()
+                        .withCreator(entry.getValue().auditInfo().creator())
+                        .withCreateTime(entry.getValue().auditInfo().createTime())
+                        .withLastModifier(PrincipalUtils.getCurrentPrincipal().getName())
+                        .withLastModifiedTime(Instant.now())
+                        .build())
+                .build();
+
+        columnsNeedsUpdate = true;
+        columnsToInsert.add(updatedColumnEntity);
+
+      } else {
+        // If the column is the same, we keep the original ColumnEntity
+        columnsToInsert.add(entry.getValue());
+      }
+    }
+
+    // Check if there are new columns in the table from the underlying source
+    for (Map.Entry<String, Pair<Integer, Column>> entry : columnsFromCatalogTable.entrySet()) {
+      if (!columnsFromTableEntity.containsKey(entry.getKey())) {
+        LOG.debug(
+            "Column {} is found in the table from underlying source but not in the table "
+                + "entity, it will be added to the table entity",
+            entry.getKey());
+        ColumnEntity newColumnEntity =
+            ColumnEntity.toColumnEntity(
+                entry.getValue().getRight(),
+                entry.getValue().getLeft(),
+                idGenerator.nextId(),
+                AuditInfo.builder()
+                    .withCreator(PrincipalUtils.getCurrentPrincipal().getName())
+                    .withCreateTime(Instant.now())
+                    .build());
+
+        columnsNeedsUpdate = true;
+        columnsToInsert.add(newColumnEntity);
+      }
+    }
+
+    return Pair.of(columnsNeedsUpdate, columnsToInsert);
+  }
+
+  private TableEntity updateColumnsIfNecessaryWhenLoad(
+      NameIdentifier tableIdent, EntityCombinedTable combinedTable) {
+    Pair<Boolean, List<ColumnEntity>> columnsUpdateResult =
+        updateColumnsIfNecessary(
+            combinedTable.tableFromCatalog(), combinedTable.tableFromGravitino());
+
+    // No need to update the columns
+    if (!columnsUpdateResult.getLeft()) {
+      return combinedTable.tableFromGravitino();
+    }
+
+    // Update the columns in the Gravitino store
+    return TreeLockUtils.doWithTreeLock(
+        tableIdent,
+        LockType.WRITE,
+        () ->
+            operateOnEntity(
+                tableIdent,
+                id ->
+                    store.update(
+                        id,
+                        TableEntity.class,
+                        TABLE,
+                        entity ->
+                            TableEntity.builder()
+                                .withId(entity.id())
+                                .withName(entity.name())
+                                .withNamespace(entity.namespace())
+                                .withColumns(columnsUpdateResult.getRight())
+                                .withAuditInfo(
+                                    AuditInfo.builder()
+                                        .withCreator(entity.auditInfo().creator())
+                                        .withCreateTime(entity.auditInfo().createTime())
+                                        .withLastModifier(
+                                            PrincipalUtils.getCurrentPrincipal().getName())
+                                        .withLastModifiedTime(Instant.now())
+                                        .build())
+                                .build()),
+                "UPDATE",
+                combinedTable.tableFromGravitino().id()));
+  }
 }
