@@ -64,10 +64,8 @@ import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInstance;
 
 @Tag("gravitino-docker-test")
-@TestInstance(TestInstance.Lifecycle.PER_CLASS)
 public class FlinkHiveCatalogIT extends FlinkCommonIT {
   private static final String DEFAULT_HIVE_CATALOG = "test_flink_hive_schema_catalog";
 
@@ -81,7 +79,7 @@ public class FlinkHiveCatalogIT extends FlinkCommonIT {
   @AfterAll
   static void hiveStop() {
     Preconditions.checkNotNull(metalake);
-    metalake.dropCatalog(DEFAULT_HIVE_CATALOG);
+    metalake.dropCatalog(DEFAULT_HIVE_CATALOG, true);
   }
 
   protected static void initDefaultHiveCatalog() {
