@@ -19,21 +19,30 @@
 
 package org.apache.gravitino.iceberg.common;
 
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableMap;
+import java.util.Collections;
+import java.util.List;
 import java.util.Map;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.gravitino.Config;
+import org.apache.gravitino.OverwriteDefaultConfig;
 import org.apache.gravitino.catalog.lakehouse.iceberg.IcebergConstants;
 import org.apache.gravitino.catalog.lakehouse.iceberg.IcebergPropertiesUtils;
 import org.apache.gravitino.config.ConfigBuilder;
 import org.apache.gravitino.config.ConfigConstants;
 import org.apache.gravitino.config.ConfigEntry;
-import org.apache.gravitino.server.web.JettyServerConfig;
-import org.apache.gravitino.server.web.OverwriteDefaultConfig;
+import org.apache.gravitino.credential.CredentialConstants;
+import org.apache.gravitino.storage.OSSProperties;
+import org.apache.gravitino.storage.S3Properties;
 
 public class IcebergConfig extends Config implements OverwriteDefaultConfig {
 
   public static final String ICEBERG_CONFIG_PREFIX = "gravitino.iceberg-rest.";
+  @VisibleForTesting public static final String ICEBERG_EXTENSION_PACKAGES = "extension-packages";
+
+  public static final int DEFAULT_ICEBERG_REST_SERVICE_HTTP_PORT = 9001;
+  public static final int DEFAULT_ICEBERG_REST_SERVICE_HTTPS_PORT = 9433;
 
   public static final ConfigEntry<String> CATALOG_BACKEND =
       new ConfigBuilder(IcebergConstants.CATALOG_BACKEND)
@@ -42,6 +51,15 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
           .stringConf()
           .createWithDefault("memory");
 
+  public static final ConfigEntry<String> CATALOG_BACKEND_IMPL =
+      new ConfigBuilder(IcebergConstants.CATALOG_BACKEND_IMPL)
+          .doc(
+              "The fully-qualified class name of a custom catalog implementation, "
+                  + "only worked if `catalog-backend` is `custom`")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
   public static final ConfigEntry<String> CATALOG_WAREHOUSE =
       new ConfigBuilder(IcebergConstants.WAREHOUSE)
           .doc("Warehouse directory of catalog")
@@ -96,7 +114,7 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
           .create();
 
   public static final ConfigEntry<String> S3_ENDPOINT =
-      new ConfigBuilder(IcebergConstants.GRAVITINO_S3_ENDPOINT)
+      new ConfigBuilder(S3Properties.GRAVITINO_S3_ENDPOINT)
           .doc(
               "An alternative endpoint of the S3 service, This could be used to for S3FileIO with "
                   + "any s3-compatible object storage service that has a different endpoint, or "
@@ -106,7 +124,7 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
           .create();
 
   public static final ConfigEntry<String> S3_REGION =
-      new ConfigBuilder(IcebergConstants.GRAVITINO_S3_REGION)
+      new ConfigBuilder(S3Properties.GRAVITINO_S3_REGION)
           .doc("The region of the S3 service")
           .version(ConfigConstants.VERSION_0_6_0)
           .stringConf()
@@ -114,19 +132,40 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
           .create();
 
   public static final ConfigEntry<String> S3_ACCESS_KEY_ID =
-      new ConfigBuilder(IcebergConstants.GRAVITINO_S3_ACCESS_KEY_ID)
+      new ConfigBuilder(S3Properties.GRAVITINO_S3_ACCESS_KEY_ID)
           .doc("The static access key ID used to access S3 data")
           .version(ConfigConstants.VERSION_0_6_0)
           .stringConf()
           .create();
 
   public static final ConfigEntry<String> S3_SECRET_ACCESS_KEY =
-      new ConfigBuilder(IcebergConstants.GRAVITINO_S3_SECRET_ACCESS_KEY)
+      new ConfigBuilder(S3Properties.GRAVITINO_S3_SECRET_ACCESS_KEY)
           .doc("The static secret access key used to access S3 data")
           .version(ConfigConstants.VERSION_0_6_0)
           .stringConf()
           .create();
 
+  public static final ConfigEntry<String> OSS_ENDPOINT =
+      new ConfigBuilder(OSSProperties.GRAVITINO_OSS_ENDPOINT)
+          .doc("The endpoint of Aliyun OSS service")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
+  public static final ConfigEntry<String> OSS_ACCESS_KEY_ID =
+      new ConfigBuilder(OSSProperties.GRAVITINO_OSS_ACCESS_KEY_ID)
+          .doc("The static access key ID used to access OSS data")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
+  public static final ConfigEntry<String> OSS_ACCESS_KEY_SECRET =
+      new ConfigBuilder(OSSProperties.GRAVITINO_OSS_ACCESS_KEY_SECRET)
+          .doc("The static access key secret used to access OSS data")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
   public static final ConfigEntry<String> ICEBERG_METRICS_STORE =
       new ConfigBuilder(IcebergConstants.ICEBERG_METRICS_STORE)
           .doc("The store to save Iceberg metrics")
@@ -137,7 +176,8 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
   public static final ConfigEntry<Integer> ICEBERG_METRICS_STORE_RETAIN_DAYS =
       new ConfigBuilder(IcebergConstants.ICEBERG_METRICS_STORE_RETAIN_DAYS)
           .doc(
-              "The retain days of Iceberg metrics, the value not greater than 0 means retain forever")
+              "The retain days of Iceberg metrics, the value not greater than 0 means "
+                  + "retain forever")
           .version(ConfigConstants.VERSION_0_4_0)
           .intConf()
           .createWithDefault(-1);
@@ -157,6 +197,56 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
           .stringConf()
           .create();
 
+  public static final ConfigEntry<Long> ICEBERG_REST_CATALOG_CACHE_EVICTION_INTERVAL =
+      new ConfigBuilder(IcebergConstants.ICEBERG_REST_CATALOG_CACHE_EVICTION_INTERVAL)
+          .doc("Catalog cache eviction interval.")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .longConf()
+          .createWithDefault(3600000L);
+
+  public static final ConfigEntry<String> ICEBERG_REST_CATALOG_CONFIG_PROVIDER =
+      new ConfigBuilder(IcebergConstants.ICEBERG_REST_CATALOG_CONFIG_PROVIDER)
+          .doc(
+              "Catalog provider class name, you can develop a class that implements "
+                  + "`IcebergConfigProvider` and add the corresponding jar file to the Iceberg "
+                  + "REST service classpath directory.")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .createWithDefault(IcebergConstants.STATIC_ICEBERG_CATALOG_CONFIG_PROVIDER_NAME);
+
+  public static final ConfigEntry<String> GRAVITINO_URI =
+      new ConfigBuilder(IcebergConstants.GRAVITINO_URI)
+          .doc(
+              "The uri of Gravitino server address, only worked if `catalog-provider` is "
+                  + "`gravitino-based-provider`.")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
+  public static final ConfigEntry<String> GRAVITINO_METALAKE =
+      new ConfigBuilder(IcebergConstants.GRAVITINO_METALAKE)
+          .doc(
+              "The metalake name that `gravitino-based-provider` used to request to Gravitino, "
+                  + "only worked if `catalog-provider` is `gravitino-based-provider`.")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
+  public static final ConfigEntry<List<String>> REST_API_EXTENSION_PACKAGES =
+      new ConfigBuilder(ICEBERG_EXTENSION_PACKAGES)
+          .doc("Comma-separated list of Iceberg REST API packages to expand")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .toSequence()
+          .createWithDefault(Collections.emptyList());
+
+  public static final ConfigEntry<String> CREDENTIAL_PROVIDER_TYPE =
+      new ConfigBuilder(CredentialConstants.CREDENTIAL_PROVIDER_TYPE)
+          .doc("The credential provider type for Iceberg")
+          .version(ConfigConstants.VERSION_0_7_0)
+          .stringConf()
+          .create();
+
   public String getJdbcDriver() {
     return get(JDBC_DRIVER);
   }
@@ -185,9 +275,9 @@ public class IcebergConfig extends Config implements OverwriteDefaultConfig {
   @Override
   public Map<String, String> getOverwriteDefaultConfig() {
     return ImmutableMap.of(
-        JettyServerConfig.WEBSERVER_HTTP_PORT.getKey(),
-        String.valueOf(JettyServerConfig.DEFAULT_ICEBERG_REST_SERVICE_HTTP_PORT),
-        JettyServerConfig.WEBSERVER_HTTPS_PORT.getKey(),
-        String.valueOf(JettyServerConfig.DEFAULT_ICEBERG_REST_SERVICE_HTTPS_PORT));
+        ConfigConstants.WEBSERVER_HTTP_PORT,
+        String.valueOf(DEFAULT_ICEBERG_REST_SERVICE_HTTP_PORT),
+        ConfigConstants.WEBSERVER_HTTPS_PORT,
+        String.valueOf(DEFAULT_ICEBERG_REST_SERVICE_HTTPS_PORT));
   }
 }
