@@ -39,6 +39,7 @@ import org.apache.gravitino.iceberg.common.authentication.kerberos.KerberosClien
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hdfs.HdfsConfiguration;
 import org.apache.iceberg.CatalogProperties;
+import org.apache.iceberg.CatalogUtil;
 import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.hive.HiveCatalog;
 import org.apache.iceberg.inmemory.InMemoryCatalog;
@@ -99,8 +100,11 @@ public class IcebergCatalogUtil {
       Map<String, String> properties, Configuration conf) {
     try {
       KerberosClient kerberosClient = new KerberosClient(properties, conf);
-      File keytabFile =
-          kerberosClient.saveKeyTabFileFromUri(Long.valueOf(properties.get("catalog_uuid")));
+
+      // For Iceberg rest server, we haven't set the catalog_uuid, so we set it to 0 as there is
+      // only one catalog in the rest server, so it's okay to set it to 0.
+      String catalogUUID = properties.getOrDefault("catalog_uuid", "0");
+      File keytabFile = kerberosClient.saveKeyTabFileFromUri(Long.valueOf(catalogUUID));
       kerberosClient.login(keytabFile.getAbsolutePath());
       return kerberosClient;
     } catch (IOException e) {
@@ -146,6 +150,16 @@ public class IcebergCatalogUtil {
     return restCatalog;
   }
 
+  private static Catalog loadCustomCatalog(IcebergConfig icebergConfig) {
+    String customCatalogName = icebergConfig.getCatalogBackendName();
+    String className = icebergConfig.get(IcebergConfig.CATALOG_BACKEND_IMPL);
+    return CatalogUtil.loadCatalog(
+        className,
+        customCatalogName,
+        icebergConfig.getIcebergCatalogProperties(),
+        new HdfsConfiguration());
+  }
+
   @VisibleForTesting
   static Catalog loadCatalogBackend(String catalogType) {
     return loadCatalogBackend(
@@ -165,6 +179,8 @@ public class IcebergCatalogUtil {
         return loadJdbcCatalog(icebergConfig);
       case REST:
         return loadRestCatalog(icebergConfig);
+      case CUSTOM:
+        return loadCustomCatalog(icebergConfig);
       default:
         throw new RuntimeException(
             catalogBackend
