@@ -18,12 +18,18 @@
  */
 package org.apache.gravitino.server.web;
 
+import com.google.common.collect.Maps;
 import java.security.PrivilegedExceptionAction;
+import java.util.Map;
 import java.util.Optional;
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.gravitino.UserPrincipal;
+import org.apache.gravitino.audit.FilesetAuditConstants;
+import org.apache.gravitino.audit.FilesetDataOperation;
+import org.apache.gravitino.audit.InternalClientType;
 import org.apache.gravitino.auth.AuthConstants;
 import org.apache.gravitino.dto.responses.ErrorResponse;
 import org.apache.gravitino.utils.PrincipalUtils;
@@ -116,6 +122,28 @@ public class Utils {
         .build();
   }
 
+  public static Response notInUse(String message, Throwable throwable) {
+    return notInUse(throwable.getClass().getSimpleName(), message, throwable);
+  }
+
+  public static Response notInUse(String type, String message, Throwable throwable) {
+    return Response.status(Response.Status.CONFLICT)
+        .entity(ErrorResponse.notInUse(type, message, throwable))
+        .type(MediaType.APPLICATION_JSON)
+        .build();
+  }
+
+  public static Response inUse(String message, Throwable throwable) {
+    return inUse(throwable.getClass().getSimpleName(), message, throwable);
+  }
+
+  public static Response inUse(String type, String message, Throwable throwable) {
+    return Response.status(Response.Status.CONFLICT)
+        .entity(ErrorResponse.inUse(type, message, throwable))
+        .type(MediaType.APPLICATION_JSON)
+        .build();
+  }
+
   public static Response nonEmpty(String type, String message) {
     return nonEmpty(type, message, null);
   }
@@ -142,6 +170,13 @@ public class Utils {
         .build();
   }
 
+  public static Response forbidden(String message, Throwable throwable) {
+    return Response.status(Response.Status.FORBIDDEN)
+        .entity(ErrorResponse.forbidden(message, throwable))
+        .type(MediaType.APPLICATION_JSON)
+        .build();
+  }
+
   public static Response doAs(
       HttpServletRequest httpRequest, PrivilegedExceptionAction<Response> action) throws Exception {
     UserPrincipal principal =
@@ -152,4 +187,30 @@ public class Utils {
     }
     return PrincipalUtils.doAs(principal, action);
   }
+
+  public static Map<String, String> filterFilesetAuditHeaders(HttpServletRequest httpRequest) {
+    Map<String, String> filteredHeaders = Maps.newHashMap();
+
+    String internalClientType =
+        httpRequest.getHeader(FilesetAuditConstants.HTTP_HEADER_INTERNAL_CLIENT_TYPE);
+    if (StringUtils.isNotBlank(internalClientType)) {
+      filteredHeaders.put(
+          FilesetAuditConstants.HTTP_HEADER_INTERNAL_CLIENT_TYPE,
+          InternalClientType.checkValid(internalClientType)
+              ? internalClientType
+              : InternalClientType.UNKNOWN.name());
+    }
+
+    String dataOperation =
+        httpRequest.getHeader(FilesetAuditConstants.HTTP_HEADER_FILESET_DATA_OPERATION);
+    if (StringUtils.isNotBlank(
+        httpRequest.getHeader(FilesetAuditConstants.HTTP_HEADER_FILESET_DATA_OPERATION))) {
+      filteredHeaders.put(
+          FilesetAuditConstants.HTTP_HEADER_FILESET_DATA_OPERATION,
+          FilesetDataOperation.checkValid(dataOperation)
+              ? dataOperation
+              : FilesetDataOperation.UNKNOWN.name());
+    }
+    return filteredHeaders;
+  }
 }
