@@ -50,6 +50,8 @@ import org.apache.gravitino.dto.responses.DeleteResponse;
 import org.apache.gravitino.dto.responses.NameListResponse;
 import org.apache.gravitino.dto.responses.RoleResponse;
 import org.apache.gravitino.dto.util.DTOConverters;
+import org.apache.gravitino.exceptions.IllegalMetadataObjectException;
+import org.apache.gravitino.exceptions.NoSuchMetadataObjectException;
 import org.apache.gravitino.lock.LockType;
 import org.apache.gravitino.lock.TreeLockUtils;
 import org.apache.gravitino.metrics.MetricNames;
@@ -143,7 +145,11 @@ public class RoleOperations {
               for (Privilege privilege : object.privileges()) {
                 AuthorizationUtils.checkPrivilege((PrivilegeDTO) privilege, object, metalake);
               }
-              MetadataObjectUtil.checkMetadataObject(metalake, object);
+              try {
+                MetadataObjectUtil.checkMetadataObject(metalake, object);
+              } catch (NoSuchMetadataObjectException nsm) {
+                throw new IllegalMetadataObjectException(nsm);
+              }
             }
 
             List<SecurableObject> securableObjects =
